@@ -1,10 +1,13 @@
 package Calendar::Indonesia::Holiday;
 
+our $DATE = '2015-04-28'; # DATE
+our $VERSION = '0.24'; # VERSION
+
 use 5.010001;
 use strict;
 use warnings;
 use experimental 'smartmatch';
-use Log::Any '$log';
+use Log::Any::IfLOG '$log';
 
 use DateTime;
 use Function::Fallback::CoreOrPP qw(clone);
@@ -19,10 +22,13 @@ our @EXPORT_OK = qw(
                        count_id_workdays
                );
 
-our $VERSION = '0.23'; # VERSION
-our $DATE = '2014-08-16'; # DATE
-
 our %SPEC;
+
+$SPEC{':package'} = {
+    v => 1.1,
+    summary => 'List Indonesian public holidays',
+};
+
 my @fixed_holidays = (
     my $newyear = {
         day        =>  1, month =>  1,
@@ -613,6 +619,26 @@ $year_holidays{2015} = [
     _jointlv     ({_expand_dm("24-12")}, {holiday=>$christmas}),
 ];
 
+# tentative
+#
+# ref:
+# - http://id.wikipedia.org/wiki/2016#Hari_libur_nasional_di_Indonesia
+my $eidulf2016;
+$year_holidays{2016} = [
+    _h_chnewyear ({_expand_dm("08-02")}, {hyear=>2567}),
+    _h_nyepi     ({_expand_dm("09-03")}, {hyear=>1938}),
+    _h_goodfri   ({_expand_dm("25-03")}),
+    _h_isramiraj ({_expand_dm("04-05")}),
+    _h_ascension ({_expand_dm("05-05")}),
+    _h_vesakha   ({_expand_dm("22-05")}, {hyear=>2560}),
+    _h_eidulf    ({_expand_dm("06-07")}, {hyear=>1437, day=>1}),
+    _h_eidulf    ({_expand_dm("07-07")}, {hyear=>1437, day=>2}),
+    _h_eidula    ({_expand_dm("13-09")}, {hyear=>1437}),
+    _h_hijra     ({_expand_dm("03-10")}, {hyear=>1438}),
+    _h_mawlid    ({_expand_dm("12-12")}),
+];
+
+
 my @years     = sort keys %year_holidays;
 our $min_year = $years[0];
 our $max_year = $years[-1];
@@ -936,7 +962,7 @@ Calendar::Indonesia::Holiday - List Indonesian public holidays
 
 =head1 VERSION
 
-This document describes version 0.23 of Calendar::Indonesia::Holiday (from Perl distribution Calendar-Indonesia-Holiday), released on 2014-08-16.
+This document describes version 0.24 of Calendar::Indonesia::Holiday (from Perl distribution Calendar-Indonesia-Holiday), released on 2015-04-28.
 
 =head1 SYNOPSIS
 
@@ -1003,10 +1029,6 @@ This document describes version 0.23 of Calendar::Indonesia::Holiday (from Perl
 
 This module provides functions to list Indonesian holidays.
 
-This module uses L<Log::Any> logging framework.
-
-This module has L<Rinci> metadata.
-
 =head1 FUNCTIONS
 
 
@@ -1019,7 +1041,7 @@ days*. If work_saturdays is set to true, Saturdays are also counted as working
 days. If observe_joint_leaves is set to false, joint leave days are also counted
 as working days.
 
-Contains data from years 2002 to 2015 (joint leave days until
+Contains data from years 2002 to 2016 (joint leave days until
 2015).
 
 Arguments ('*' denotes required arguments):
@@ -1050,8 +1072,6 @@ If set to 1, Saturday is a working day.
 
 =back
 
-Return value:
-
 Returns an enveloped result (an array).
 
 First element (status) is an integer containing HTTP status code
@@ -1061,7 +1081,7 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
- (any)
+Return value:  (any)
 
 
 =head2 enum_id_workdays(%args) -> [status, msg, result, meta]
@@ -1073,7 +1093,7 @@ days*. If work_saturdays is set to true, Saturdays are also counted as working
 days. If observe_joint_leaves is set to false, joint leave days are also counted
 as working days.
 
-Contains data from years 2002 to 2015 (joint leave days until
+Contains data from years 2002 to 2016 (joint leave days until
 2015).
 
 Arguments ('*' denotes required arguments):
@@ -1104,8 +1124,6 @@ If set to 1, Saturday is a working day.
 
 =back
 
-Return value:
-
 Returns an enveloped result (an array).
 
 First element (status) is an integer containing HTTP status code
@@ -1115,7 +1133,7 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
- (any)
+Return value:  (any)
 
 
 =head2 list_id_holidays(%args) -> [status, msg, result, meta]
@@ -1124,7 +1142,7 @@ List Indonesian holidays in calendar.
 
 List holidays and joint leave days ("cuti bersama").
 
-Contains data from years 2002 to 2015 (joint leave days until
+Contains data from years 2002 to 2016 (joint leave days until
 2015).
 
 Arguments ('*' denotes required arguments):
@@ -1135,7 +1153,7 @@ Arguments ('*' denotes required arguments):
 
 Only return records where the 'date' field equals specified value.
 
-=item * B<date.in> => I<array>
+=item * B<date.in> => I<array[date]>
 
 Only return records where the 'date' field is in the specified values.
 
@@ -1155,7 +1173,7 @@ Only return records where the 'date' field is less than or equal to specified va
 
 Only return records where the 'date' field is greater than or equal to specified value.
 
-=item * B<date.not_in> => I<array>
+=item * B<date.not_in> => I<array[date]>
 
 Only return records where the 'date' field is not in the specified values.
 
@@ -1171,7 +1189,7 @@ Only return records where the 'date' field is greater than specified value.
 
 Only return records where the 'day' field equals specified value.
 
-=item * B<day.in> => I<array>
+=item * B<day.in> => I<array[int]>
 
 Only return records where the 'day' field is in the specified values.
 
@@ -1191,7 +1209,7 @@ Only return records where the 'day' field is less than or equal to specified val
 
 Only return records where the 'day' field is greater than or equal to specified value.
 
-=item * B<day.not_in> => I<array>
+=item * B<day.not_in> => I<array[int]>
 
 Only return records where the 'day' field is not in the specified values.
 
@@ -1211,7 +1229,7 @@ Only return records where the 'decree_date' field equals specified value.
 
 Only return records where the 'decree_date' field contains specified text.
 
-=item * B<decree_date.in> => I<array>
+=item * B<decree_date.in> => I<array[str]>
 
 Only return records where the 'decree_date' field is in the specified values.
 
@@ -1235,7 +1253,7 @@ Only return records where the 'decree_date' field is greater than or equal to sp
 
 Only return records where the 'decree_date' field does not contain specified text.
 
-=item * B<decree_date.not_in> => I<array>
+=item * B<decree_date.not_in> => I<array[str]>
 
 Only return records where the 'decree_date' field is not in the specified values.
 
@@ -1255,7 +1273,7 @@ Only return records where the 'decree_note' field equals specified value.
 
 Only return records where the 'decree_note' field contains specified text.
 
-=item * B<decree_note.in> => I<array>
+=item * B<decree_note.in> => I<array[str]>
 
 Only return records where the 'decree_note' field is in the specified values.
 
@@ -1279,7 +1297,7 @@ Only return records where the 'decree_note' field is greater than or equal to sp
 
 Only return records where the 'decree_note' field does not contain specified text.
 
-=item * B<decree_note.not_in> => I<array>
+=item * B<decree_note.not_in> => I<array[str]>
 
 Only return records where the 'decree_note' field is not in the specified values.
 
@@ -1301,7 +1319,7 @@ By default, only the key (ID) field is returned per result entry.
 
 Only return records where the 'dow' field equals specified value.
 
-=item * B<dow.in> => I<array>
+=item * B<dow.in> => I<array[int]>
 
 Only return records where the 'dow' field is in the specified values.
 
@@ -1321,7 +1339,7 @@ Only return records where the 'dow' field is less than or equal to specified val
 
 Only return records where the 'dow' field is greater than or equal to specified value.
 
-=item * B<dow.not_in> => I<array>
+=item * B<dow.not_in> => I<array[int]>
 
 Only return records where the 'dow' field is not in the specified values.
 
@@ -1333,7 +1351,7 @@ Only return records where the 'dow' field is less than specified value.
 
 Only return records where the 'dow' field is greater than specified value.
 
-=item * B<fields> => I<array>
+=item * B<fields> => I<array[str]>
 
 Select fields to return.
 
@@ -1365,7 +1383,7 @@ Only return records where the 'is_joint_leave' field does not equal specified va
 
 Only return records where the 'month' field equals specified value.
 
-=item * B<month.in> => I<array>
+=item * B<month.in> => I<array[int]>
 
 Only return records where the 'month' field is in the specified values.
 
@@ -1385,7 +1403,7 @@ Only return records where the 'month' field is less than or equal to specified v
 
 Only return records where the 'month' field is greater than or equal to specified value.
 
-=item * B<month.not_in> => I<array>
+=item * B<month.not_in> => I<array[int]>
 
 Only return records where the 'month' field is not in the specified values.
 
@@ -1405,7 +1423,7 @@ Only return records where the 'note' field equals specified value.
 
 Only return records where the 'note' field contains specified text.
 
-=item * B<note.in> => I<array>
+=item * B<note.in> => I<array[str]>
 
 Only return records where the 'note' field is in the specified values.
 
@@ -1429,7 +1447,7 @@ Only return records where the 'note' field is greater than or equal to specified
 
 Only return records where the 'note' field does not contain specified text.
 
-=item * B<note.not_in> => I<array>
+=item * B<note.not_in> => I<array[str]>
 
 Only return records where the 'note' field is not in the specified values.
 
@@ -1441,7 +1459,7 @@ Only return records where the 'note' field is less than specified value.
 
 Only return records where the 'note' field is greater than specified value.
 
-=item * B<q> => I<str>
+=item * B<query> => I<str>
 
 Search.
 
@@ -1468,7 +1486,7 @@ specify descending order instead of the default ascending.
 
 Only return records where the 'tags' field equals specified value.
 
-=item * B<tags.has> => I<array>
+=item * B<tags.has> => I<array[str]>
 
 Only return records where the 'tags' field is an array/list which contains specified value.
 
@@ -1480,7 +1498,7 @@ Only return records where the 'tags' field equals specified value.
 
 Only return records where the 'tags' field does not equal specified value.
 
-=item * B<tags.lacks> => I<array>
+=item * B<tags.lacks> => I<array[str]>
 
 Only return records where the 'tags' field is an array/list which does not contain specified value.
 
@@ -1496,7 +1514,7 @@ as list/array (field value, field value, ...).
 
 Only return records where the 'year' field equals specified value.
 
-=item * B<year.in> => I<array>
+=item * B<year.in> => I<array[int]>
 
 Only return records where the 'year' field is in the specified values.
 
@@ -1516,7 +1534,7 @@ Only return records where the 'year' field is less than or equal to specified va
 
 Only return records where the 'year' field is greater than or equal to specified value.
 
-=item * B<year.not_in> => I<array>
+=item * B<year.not_in> => I<array[int]>
 
 Only return records where the 'year' field is not in the specified values.
 
@@ -1530,8 +1548,6 @@ Only return records where the 'year' field is greater than specified value.
 
 =back
 
-Return value:
-
 Returns an enveloped result (an array).
 
 First element (status) is an integer containing HTTP status code
@@ -1541,7 +1557,7 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
- (any)
+Return value:  (any)
 
 
 =head2 list_id_workdays(%args) -> [status, msg, result, meta]
@@ -1560,8 +1576,6 @@ Arguments ('*' denotes required arguments):
 
 =back
 
-Return value:
-
 Returns an enveloped result (an array).
 
 First element (status) is an integer containing HTTP status code
@@ -1571,7 +1585,7 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
- (any)
+Return value:  (any)
 
 =head1 FAQ
 
@@ -1609,7 +1623,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Calendar-I
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Calendar-Indonesia-Holiday>.
+Source repository is at L<https://github.com/perlancar/perl-Calendar-Indonesia-Holiday>.
 
 =head1 BUGS
 
@@ -1621,11 +1635,11 @@ feature.
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steven Haryanto.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
